FFNGM: Fitting and Forecasting using Nonlinear Growth Models
Description
The FFNGM function fits nonlinear growth models to time series data and computes the h step ahead forecast values.
Usage
FFNGM (x, t, model=c("Monomolecular", "Logistic", "Gompertz"), k, y, r, h)
Arguments
x
a univariate time series data.
t
a numeric vector containing time points.
model
<U+201C>Monomolecular<U+201D> or <U+201C>Logistic<U+201D> or <U+201C>Gompertz<U+201D>.
k
Initial estimate of carrying capacity (maximum limit of the considered time series data).
y
Initial estimate of starting value of the considered time series data.
r
Initial estimate of growth rate.
h
The forecast horizon.
Value
modelsummary
Summary of the fitted model
fitted.values
Fitted values of the model
MAE
Mean Absolute Error (MAE) of the fitted model
MAPE
Mean Absolute Percentage Error (MAPE) of the fitted model
MSE
Mean Square Error (MSE) of fitted the model
RMSE
Root Mean Square Error (RMSE) of the fitted model
forecasted.values
h step ahead forecasted values of the fitted Model
Details
Using the nonlinear least squares method, this function estimates the parameters of nonlinear growth models for time series data. This function returns the fitted model summary, as well as the model's fitted values and various evaluation criteria. This function also returns the fitted model's h step ahead forecasted values.
References
Pal, S. and Mazumder, D. (2015). Forecasting groundnut production of India using nonlinear growth models. Journal Crop and Weed, 11, 67-70.
Seber, G. A.F. and Wild, C. J. 2003. Nonlinear Regression, 2, New York: John Wiley.